@@ -81,8 +81,8 @@ class BetaGeoBetaBinomFitter(BaseFitter):
 
     @staticmethod
     def _negative_log_likelihood(params, frequency, recency, n, n_custs, penalizer_coef=0):
-        penalizer_term = penalizer_coef * log(params).sum()
-        return -np.sum(BetaGeoBetaBinomFitter._loglikelihood(params, frequency, recency, n) * n_custs) + penalizer_term
+        penalizer_term = penalizer_coef * sum(np.asarray(params) ** 2)
+        return -np.mean(BetaGeoBetaBinomFitter._loglikelihood(params, frequency, recency, n) * n_custs) + penalizer_term
 
     def fit(self, frequency, recency, n, n_custs, verbose=False, tol=1e-4, iterative_fitting=1):
         """
@@ -261,8 +261,8 @@ class GammaGammaFitter(BaseFitter):
                                           (p * x - 1) * np.log(m) +
                                           (p * x) * np.log(x) -
                                           (p * x + q) * np.log(x * m + v))
-        penalizer_term = penalizer_coef * log(params).sum()
-        return -np.sum(negative_log_likelihood_values) + penalizer_term
+        penalizer_term = penalizer_coef * sum(np.asarray(params) ** 2)
+        return -np.mean(negative_log_likelihood_values) + penalizer_term
 
     def conditional_expected_average_profit(self, frequency=None, monetary_value=None):
         """
@@ -418,8 +418,8 @@ class ParetoNBDFitter(BaseFitter):
 
         A_2 = logaddexp(-(r + x) * log(alpha + T) - s * log(beta + T), log(s) + log_A_0 - log(r_s_x))
 
-        penalizer_term = penalizer_coef * log(params).sum()
-        return -(A_1 + A_2).sum() + penalizer_term
+        penalizer_term = penalizer_coef * sum(np.asarray(params) ** 2)
+        return -(A_1 + A_2).mean() + penalizer_term
 
     def conditional_probability_alive(self, frequency, recency, T):
         """
@@ -478,11 +478,11 @@ class ParetoNBDFitter(BaseFitter):
         params = self._unload_params('r', 'alpha', 's', 'beta')
         r, alpha, s, beta = params
 
-        likelihood = exp(-self._negative_log_likelihood(params, x, t_x, T, 0))
-        first_term = (gamma(r + x) / gamma(r)) * (alpha ** r * beta ** s) / (alpha + T) ** (r + x) / (beta + T) ** s
-        second_term = (r + x) * (beta + T) / (alpha + T) / (s - 1)
-        third_term = 1 - ((beta + T) / (beta + T + t)) ** (s - 1)
-        return first_term * second_term * third_term / likelihood
+        likelihood = -self._negative_log_likelihood(params, x, t_x, T, 0)
+        first_term = gammaln(r + x) - gammaln(r) + r*log(alpha) + s*log(beta) - (r + x)*log(alpha + T) - s*log(beta + T)
+        second_term = log(r + x) + log(beta + T) - log(alpha + T)
+        third_term = log((1 - ((beta + T) / (beta + T + t)) ** (s - 1))/(s - 1))
+        return exp(first_term + second_term + third_term - likelihood)
 
     def expected_number_of_purchases_up_to_time(self, t):
         """
@@ -577,8 +577,8 @@ class BetaGeoFitter(BaseFitter):
         d = vconcat[ones_like(freq), (freq > 0)]
         A_4 = log(a) - log(b + freq - 1) - (r + freq) * log(rec + alpha)
         A_4[isnan(A_4) | isinf(A_4)] = 0
-        penalizer_term = penalizer_coef * log(params).sum()
-        return -(A_1 + A_2 + misc.logsumexp(vconcat[A_3, A_4], axis=1, b=d)).sum() + penalizer_term
+        penalizer_term = penalizer_coef * sum(np.asarray(params) ** 2)
+        return -(A_1 + A_2 + misc.logsumexp(vconcat[A_3, A_4], axis=1, b=d)).mean() + penalizer_term
 
     def expected_number_of_purchases_up_to_time(self, t):
         """
@@ -731,8 +731,8 @@ class ModifiedBetaGeoFitter(BetaGeoFitter):
         A_3 = -(r + freq) * log(alpha + T)
         A_4 = log(a) - log(b + freq) + (r + freq) * (log(alpha + T) - log(alpha + rec))
 
-        penalizer_term = penalizer_coef * log(params).sum()
-        return -(A_1 + A_2 + A_3 + logaddexp(A_4, 0)).sum() + penalizer_term
+        penalizer_term = penalizer_coef * sum(np.asarray(params) ** 2)
+        return -(A_1 + A_2 + A_3 + logaddexp(A_4, 0)).mean() + penalizer_term
 
     def expected_number_of_purchases_up_to_time(self, t):
         """
