@@ -110,7 +110,7 @@ def find_first_transactions(transactions, customer_id_col, datetime_col, monetar
     if monetary_value_col:
         select_columns.append(monetary_value_col)
 
-    transactions = transactions[select_columns].copy()
+    transactions = transactions[select_columns].sort(select_columns).copy()
 
     # make sure the date column uses datetime objects, and use Pandas' DateTimeIndex.to_period()
     # to convert the column to a PeriodIndex which is useful for time-wise grouping and truncating
@@ -189,7 +189,6 @@ def summary_data_from_transaction_data(transactions, customer_id_col, datetime_c
         # by setting the monetary_value cells of all the first purchases to NaN,
         # those values will be excluded from the mean value calculation
         repeated_transactions.loc[first_purchases, monetary_value_col] = np.nan
-
         customers['monetary_value'] = repeated_transactions.groupby(customer_id_col)[monetary_value_col].mean().fillna(0)
         summary_columns.append('monetary_value')
 
@@ -223,7 +222,7 @@ def calculate_alive_path(model, transactions, datetime_col, t, freq='D'):
     return customer_history.apply(lambda row: model.conditional_probability_alive(row['frequency'], row['recency'], row['T']), axis=1)
 
 
-def _fit(minimizing_function, minimizing_function_args, iterative_fitting, initial_params, params_size, disp, tol=1e-4):
+def _fit(minimizing_function, minimizing_function_args, iterative_fitting, initial_params, params_size, disp, tol=1e-8):
     ll = []
     sols = []
 
@@ -272,7 +271,7 @@ def customer_lifetime_value(transaction_prediction_model, frequency, recency, T,
     """
     This method computes the average lifetime value for a group of one or more customers.
         transaction_prediction_model: the model to predict future transactions, literature uses
-            pareto/ndb but we can also use a different model like bg
+            pareto/nbd but we can also use a different model like bg
         frequency: the frequency vector of customers' purchases (denoted x in literature).
         recency: the recency vector of customers' purchases (denoted t_x in literature).
         T: the vector of customers' age (time since first purchase)
